
from pybanner.pybanner import MIDDOT
from pybanner.pybanner import banner, banner3, banner3d, banner4
from pybanner.pybanner import banner_clr4x6
from pybanner.pybanner import banner_clr5x6, banner_clr5x8, banner_clr5x10, banner_5x7, banner_5x8
from pybanner.pybanner import banner_clr6x6, banner_clr6x8, banner_clr6x10, banner_6x9, banner_6x10
from pybanner.pybanner import banner_clb6x10
from pybanner.pybanner import banner_clr7x8, banner_clr7x10
from pybanner.pybanner import banner_clr8x8, banner_clb8x8, banner_clr8x10, banner_clb8x10 



import codecs
from setuptools import setup, find_packages

setup(
    name='pybanner',
    version='1.0.3',
    description="A small and lightweight library for Python 3.x and PyPy3 to print texts as banners. Works on Linux, MacOS and Windows. No Figlet, Toilet or PyFiglet needed, it's Pure Python!",
    url='https://github.com/rabuchaim/pybanner',
    author='Ricardo Abuchaim',
    author_email='ricardoabuchaim@gmail.com',
    maintainer='Ricardo Abuchaim',
    maintainer_email='ricardoabuchaim@gmail.com',
    project_urls={
        "Issue Tracker": "https://github.com/rabuchaim/pybanner/issues",
        "Source code": "https://github.com/rabuchaim/pybanner",
    },    
    bugtrack_url='https://github.com/rabuchaim/pybanner/issues',    
    license='MIT',
    keywords=['pybanner','banner','figlet','pyfiglet','toilet','pure python','purepython','ascii','asciiart'],
    packages=['pybanner'],
    py_modules=['pybanner', 'pybanner'],
    package_dir = {'pybanner': 'pybanner'},
    include_package_data=True,
    zip_safe = False,
    package_data={
        'pybanner': [
            'README.md',
            'LICENSE',
            'CHANGELOG.md', 
            'pybanner/pybanner.py'
        ],
    },
    python_requires=">=3.0",
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Internet',
        'Topic :: System :: Systems Administration',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: BSD :: FreeBSD',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',  
        'Programming Language :: Python :: 3.8',  
        'Programming Language :: Python :: 3.9',  
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'License :: OSI Approved :: MIT License',
    ],
    long_description=codecs.open("README.md","r","utf-8").read(),
    long_description_content_type='text/markdown',
)
